@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2018-2022, QIIME 2 development team.
+# Copyright (c) 2018-2023, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -40,7 +40,7 @@ def _partition(table, block_size=100):
 
 
 @decorator
-def _disallow_empty_tables(wrapped_function, *args, **kwargs):
+def _validate_tables(wrapped_function, *args, **kwargs):
     bound_arguments = signature(wrapped_function).bind(*args, **kwargs)
     table = bound_arguments.arguments.get('table')
     if table is None:
@@ -66,6 +66,12 @@ def _disallow_empty_tables(wrapped_function, *args, **kwargs):
         if tab_obj.is_empty():
             raise ValueError("The provided table is empty")
 
+        if np.isnan(tab_obj.matrix_data.data).sum() > 0:
+            raise ValueError("The provided table contains NaN")
+
+        if (tab_obj.matrix_data.data < 0).sum() > 0:
+            raise ValueError("The provided table contains negative values")
+
     return wrapped_function(*args, **kwargs)
 
 
@@ -98,7 +104,7 @@ def _validate_requested_cpus(wrapped_function, *args, **kwargs):
 
     cpus_requested = b_a_arguments[param_name]
 
-    if cpus_requested == 'auto':
+    if cpus_requested == 0:
         # mutate bound_arguments.arguments 'auto' to the requested # of cpus...
         b_a_arguments[param_name] = cpus_available
         # ...and update cpus requested to prevent TypeError
